pub struct DatabentoDataClient { /* private fields */ }Expand description
A Databento data client that combines live streaming and historical data functionality.
This client uses the existing DatabentoFeedHandler for live data subscriptions
and DatabentoHistoricalClient for historical data requests. It supports multiple
datasets simultaneously, with separate feed handlers per dataset.
Implementations
Sourceimpl DatabentoDataClient
impl DatabentoDataClient
Sourcepub fn new(
client_id: ClientId,
config: DatabentoDataClientConfig,
clock: &'static AtomicTime,
) -> Result<Self>
pub fn new( client_id: ClientId, config: DatabentoDataClientConfig, clock: &'static AtomicTime, ) -> Result<Self>
Creates a new DatabentoDataClient instance.
Errors
Returns an error if client creation or publisher configuration loading fails.